/**
 * Produces friendly, standard error handling.
 *
 * As this is handling a native Error, Sentry will log it automatically.
 *
 * Displays a stack trace in development.
 *
 * ```tsx
 * const routes = [
 *   {
 *     path: '/',
 *     element: <MainLayout />,
 *     errorElement: (
 *       // 🔵 render branded UI if the error occurs high in the routing tree
 *       <AuthLayout>
 *         <ErrorBoundary />
 *       </AuthLayout>
 *     ),
 *     children: [
 *       {
 *         path: 'sub-path',
 *         element: <ChildElement />,
 *         // 🔵 renders inside the Outlet of MainLayout
 *         errorElement: <ErrorBoundary />,
 *       }
 *     ],
 *   }
 * ]
 * ```
 *
 * https://reactrouter.com/en/6.15.0/route/error-element
 */
export declare function ErrorBoundary(): import("react/jsx-runtime").JSX.Element;
