import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Alert, AlertTitle, Heading, Text, VStack, chakra, } from '@chakra-ui/react';
import { useRouteError } from 'react-router-dom';
import { SupportEmail } from '..';
const preSx = {
    p: '4',
    bg: 'red.200',
    whiteSpace: 'pre-wrap',
    wordBreak: 'break-word',
};
/**
 * Produces friendly, standard error handling.
 *
 * As this is handling a native Error, Sentry will log it automatically.
 *
 * Displays a stack trace in development.
 *
 * ```tsx
 * const routes = [
 *   {
 *     path: '/',
 *     element: <MainLayout />,
 *     errorElement: (
 *       // 🔵 render branded UI if the error occurs high in the routing tree
 *       <AuthLayout>
 *         <ErrorBoundary />
 *       </AuthLayout>
 *     ),
 *     children: [
 *       {
 *         path: 'sub-path',
 *         element: <ChildElement />,
 *         // 🔵 renders inside the Outlet of MainLayout
 *         errorElement: <ErrorBoundary />,
 *       }
 *     ],
 *   }
 * ]
 * ```
 *
 * https://reactrouter.com/en/6.15.0/route/error-element
 */
export function ErrorBoundary() {
    const error = useRouteError();
    return (_jsxs(VStack, { align: "left", gap: "4", w: "100%", children: [_jsx(Heading, { children: "Error!" }), error?.message && (_jsx(Alert, { status: "error", variant: "solid", children: _jsx(AlertTitle, { children: error.message }) })), _jsxs(Text, { children: ["We've logged the error; if you need help, please email", ' ', _jsx(SupportEmail, {}), "."] }), !import.meta.env.PROD && error?.stack && (
            // don't show the stacktrace in prod
            _jsx(chakra.pre, { sx: preSx, children: error?.stack }))] }));
}
//# sourceMappingURL=ErrorBoundary.js.map